@@ -29,7 +29,7 @@ impl epi::App for MyApp {
                 ui.text_edit_singleline(name);
             });
             ui.add(egui::Slider::u32(age, 0..=120).text("age"));
-            if ui.button("Click each year").clicked {
+            if ui.button("Click each year").clicked() {
                 *age += 1;
             }
             ui.label(format!("Hello '{}', age {}", name, age));
